( cd usr/lib ; rm -rf libbakery-2.4-2.4.so.1 )
( cd usr/lib ; ln -sf libbakery-2.4-2.4.so.1.0.0 libbakery-2.4-2.4.so.1 )
( cd usr/lib ; rm -rf libbakery-2.4.so )
( cd usr/lib ; ln -sf libbakery-2.4-2.4.so.1.0.0 libbakery-2.4.so )
